# Makefile for mingw
#
# I didn't get the Borland compiler to attach resources to the .exe correctly, so
# this makefile compiles our program using MinGW (and Borland make, but probably
# others work as well).

# Configure your path to MINGW here:
MINGW = c:\mingw\bin

SRC = src\game.cpp src\propertyobject.cpp src\enumerator.cpp src\race.cpp \
	src\util.cpp src\data.cpp src\program.cpp src\action.cpp src\featureset.cpp \
	src\expander.cpp src\selection.cpp src\loaderstate.cpp \
	src\encoding.cpp src/workerthread.cpp src/turnuploadrequest.cpp \
	src/filedownloadrequest.cpp src/turnuploadparser.cpp src/multirequest.cpp \
	src/basicrequests.cpp src/initializer.cpp src/transaction.cpp \
	src\evaluator.cpp \
	$(NETSRC) $(OSSRC)

NETSRC = src\net\http.cpp src\net\mimebuilder.cpp src\net\url.cpp src\net\socketstream.cpp \
	src\net\md5.cpp src\net\smtp.cpp src\net\mailtemplate.cpp src\net\connection.cpp \
	src\net\config.cpp

OSSRC = os\win\socket.cpp os\win\filenames.cpp os\win\thread.cpp

WSRC = wingui\api.cpp wingui\entry.cpp wingui\wingui.cpp wingui\netconfig.cpp wingui\execute.cpp \
	wingui\statuspanel.cpp wingui\networkpanel.cpp
RM = rm -f

OBJ = $(SRC:.cpp=.o)
WOBJ = $(WSRC:.cpp=.o)

MAIN = main.cpp

CXX = $(MINGW)\g++
CPP = $(MINGW)\cpp
AR = $(MINGW)\ar
INCDIR = $(MINGW)\include

CXXFLAGS = -W -Wall -O -Isrc -Ios\win -Iwingui

all: main.exe wingui.exe

libintegrator.a: $(OBJ)
	$(AR) cr libintegrator.a $(OBJ)

main.exe: libintegrator.a $(MAIN)
	$(CXX) -o main.exe $(LDFLAGS) $(CXXFLAGS) $(MAIN) libintegrator.a -lkernel32 -lws2_32

wingui.exe: libintegrator.a $(WOBJ) wingui\dialogs.rc Makefile.m
	$(MINGW)\windres --preprocessor="$(CPP)" wingui\dialogs.rc wingui\dialogs.o
	$(CXX) -o wingui.exe $(LDFLAGS) $(CXXFLAGS) $(WOBJ) wingui\dialogs.o libintegrator.a -lkernel32 -lcomdlg32 -lws2_32 -luser32 -lgdi32

depend depend.mk:
	perl depend.pl $(CXXFLAGS) $(SRC) $(WSRC) > depend.mk

clean:
	$(RM) $(OBJ)
	$(RM) $(WOBJ)
	$(RM) integrator.lib

.cpp.o:
	$(CXX) $(CXXFLAGS) -o$*.o -c $*.cpp

!include depend.mk
