/**
  *  \file socket.h
  */
#ifndef SOCKET_H_INCLUDED
#define SOCKET_H_INCLUDED

#include <windows.h>
#include <winsock2.h>
#include "util.h"

class Socket {
    SOCKET m_Socket;

    static int checkInit(int);
 public:
    Socket()
        : m_Socket(INVALID_SOCKET)
        { checkInit(0); }

    Socket(int af, int type, int proto)
        : m_Socket(::socket(checkInit(af), type, proto))
        { }

    bool isValid()
        { return m_Socket != INVALID_SOCKET; }

    bool connect(const struct sockaddr *serv_addr, int addrlen)
        { return ::connect(m_Socket, serv_addr, addrlen) == 0; }

    int write(const void* buf, unsigned int size)
        {
            WSASetLastError(0);
            return ::send(m_Socket, (const char*) buf, size, 0);
        }

    int read(void* buf, unsigned int size)
        { return ::recv(m_Socket, (char*) buf, size, 0); }

    int close()
        {
            int rv = ::closesocket(m_Socket);
            m_Socket = INVALID_SOCKET;
            return rv;
        }

    static std::string getError();

    static std::string getResolverError()
        { return getError(); }
};
#endif
