/**
  *  \file action.h
  *  \brief Action class declaration
  *  \author Stefan Reuther
  */
#ifndef ACTION_H_INCLUDED
#define ACTION_H_INCLUDED

#include <string>
#include "propertyobject.h"

class Program;
class Expander;

/** An action provided by a Program. Actions are named by standardized
    tokens ("maketurn", "play"), so many programs can provide the same
    action. The action definition consist of a command line, and an
    optional description. We have built-in descriptions for some
    standard actions. */
class Action : public PropertyObject {
    std::string m_Name;

    std::string m_CommandLine;

    std::string m_Description;

    Program& m_Program;

 public:
    /** User level. */
    enum Level {
        SimpleLevel,   /**< Displayed on action menu. */
        NormalLevel,   /**< Displayed on program menu. */
        ExpertLevel,   /**< Only if special expert menus enabled. */
        SecretLevel    /**< Never displayed on menus. */
    };
 private:
    Level m_Level;

 public:
    Action(std::string name, Program& program);

    ~Action();

    void enumerate(KVEnumerator& e);

    bool assign(std::string name, std::string value, LoaderState& st);

    std::string getDescription();

    int getPreference() const;

    std::string getName() const;

    Program& getProgram();

    std::string getCommandLine();

    void setCommandLine(std::string s);

    Level getLevel() const;

    void setLevel(Level l);
};

#endif
