/**
  *  \file net/connection.h
  *  \brief Network Connection
  *  \author Stefan Reuther
  */
#ifndef CONNECTION_H_INCLUDED
#define CONNECTION_H_INCLUDED

#include <string>
#include <cstddef>
#include "socket.h"

/** Network connection. This encapsulates the logic of opening a
    connection, some useful operations on it, lifetime management of
    the Socket object, and storage of an error message.

    Useful convention: functions returning bool usually do so by
    returning true for success, or false on failure. In the latter
    case, they set the error message.

    Protocol handlers should derive from this class. */
class Connection {
    std::string m_OurMessage;
    std::string m_ServerMessage;

 protected:
    /** Socket. Protected so than derived classes can access it. */
    Socket m_Socket;

 public:
    Connection();

    virtual ~Connection();

    bool connect(std::string host, int port);

    void close();

    bool write(const void* data, std::size_t size);

    bool write(const std::string& data);

    bool readLine(std::string& result);

    void setMessage(std::string ourmsg, std::string srvmsg);

    std::string getErrorMessage() const
        { return m_OurMessage; }

    std::string getServerErrorMessage() const
        { return m_ServerMessage; }

    Socket getSocket()
        { return m_Socket; }
};

#endif
