/**
  *  \file socketstream.cpp
  */

#include "net/socketstream.h"

#undef EOF
#define EOF -1

SocketStreambuf::SocketStreambuf(Socket fd)
    : fd(fd)
{ }

int
SocketStreambuf::overflow(int c)
{
    setg(0, 0, 0);
    if (!pptr())
        setp(buffer, buffer);

    std::ptrdiff_t w = pptr() - pbase();
    if (c != EOF) {
        *pptr() = c;
        ++w;
    }

    if (fd.write(pbase(), w) == w) {
        setp(buffer, buffer + sizeof(buffer) - 1);  // one less to allow stuffing one additional character on next call
        return 0;
    } else {
        setp(0, 0);
        return EOF;
    }
}

int
SocketStreambuf::sync()
{
    if (pptr() && pptr() > pbase())
        return overflow(EOF);
    
    return 0;
}


SocketStream::SocketStream(Socket fd)
    : std::ostream(0), sb(fd)
{
    rdbuf(&sb);
}

SocketStream::~SocketStream()
{
    sb.sync();
}
