/**
  *  \file url.h
  *  \brief URL parsing
  */
#ifndef URL_H_INCLUDED
#define URL_H_INCLUDED

#include <string>
#include "enumerator.h"

/** An URL pointing to a file resource. This represents/splits apart
    a http- or ftp-style URL, i.e. "proto://host:port/file" format

    \todo handle fragment-identifiers meaningfully. They remain part
    of the path so far, and are sent to the webserver. They are also
    processed as part of a parameter section in trimParameters(). */
class Url {
    std::string m_Protocol;
    std::string m_Host;
    std::string m_Path;
    int m_Port;
    bool m_Valid;

 public:
    Url();

    ~Url();

    bool parse(std::string s);

    std::string getProtocol() const
        { return m_Protocol; }
    std::string getHost() const
        { return m_Host; }
    std::string getPath() const
        { return m_Path; }
    int getPort() const
        { return m_Port; }

    std::string getBaseName() const;

    std::string toString() const;

    void reset()
        { m_Valid = false; }

    bool isValid() const
        { return m_Valid; }

    void trimParameters(KVEnumerator& e);

    static void trimParameters(std::string& s, KVEnumerator& e);
};



#endif
