/**
  *  \file selection.h
  *  \brief Selection class declaration
  *  \author Stefan Reuther
  */
#ifndef SELECTION_H_INCLUDED
#define SELECTION_H_INCLUDED

#include <string>

class Game;
class Race;
class Action;
class Expander;

/** Selection. Stores the user's currently selected Game, Race and
    Action, and provides an interface to expanding command and URL
    strings in that context. */
class Selection {
 public:
    Selection();

    ~Selection();

    void selectGame(Game* g);

    void selectRace(Race* r);

    void selectAction(Action* a);

    void recheckGame();

    Game* getSelectedGame() const
        { return m_Game; }

    Race* getSelectedRace() const
        { return m_Race; }

    Action* getSelectedAction() const
        { return m_Action; }

    void setVariables(Expander& exp) const;

    std::string expandString(std::string input) const;

    bool operator==(const Selection& other) const;

    bool operator!=(const Selection& other) const
        { return !operator==(other); }

 private:

    Game* m_Game;

    Race* m_Race;

    Action* m_Action;
};

#endif
