/**
  *  \file turnuploadparser.h
  *  \brief TurnUploadParser class
  *  \author Stefan Reuther
  */
#ifndef TURNUPLOADPARSER_H_INCLUDED
#define TURNUPLOADPARSER_H_INCLUDED

#include <string>

/** Parses a turn file upload reply according to Automatic Turnfile
    Upload Protocol. That protocol consists of HTML comments
    containing some meta-information that allows us to extract the
    important information out of the server's upload confirmation
    page. */
class TurnUploadParser {
    std::string m_CheckturnResult;
    std::string m_Result;
    std::string m_Registration;
 public:
    enum TurnResult {
        ResultUnknown,    /**< Unknown result. */
        ResultGood,       /**< Turn accepted successfully. */
        ResultYellow,     /**< Yellow error. */
        ResultRed,        /**< Red error. */
        ResultBad         /**< Other error. */
    };

    enum TurnRegistration {
        RegUnknown,       /**< Unknown registration. */
        RegGood,          /**< Good registration. */
        RegShareware,     /**< Shareware. */
        RegBad            /**< Bad. */
    };

    TurnUploadParser();

    ~TurnUploadParser();

    void parse(std::string s);

    void setUnknown();

    void setMailed();

    void setCopied();

    /** Get checkturn result. \returns server output if known, as
        multi-line string, HTML removed. */
    std::string getCheckturnResult() const
        { return m_CheckturnResult; }

    /** Get turn upload result. \returns keyword specifying turn file
        status. */
    std::string getResult() const
        { return m_Result; }

    /** Get registration result. \returns keyword specifying
        registration status. */
    std::string getRegistration() const
        { return m_Registration; }

    static std::string explainResult(std::string keyword, TurnResult& result);

    static std::string explainRegistration(std::string keyword, TurnRegistration& result);
};

#endif
