/**
  *  \file wingui/networkpanel.cpp
  *  \brief Network Panel Widget
  *  \author Stefan Reuther
  */

#include "networkpanel.h"
#include "execute.h"
#include "util.h"

static const char CLASS_NAME[] = "Wingui.Networkpanel.Class";


HFONT NetworkPanel::m_Font;
int NetworkPanel::m_DefaultHeight, NetworkPanel::m_DefaultWidth;

NetworkPanel::NetworkPanel(Executer& exec)
    : m_Exec(exec)
{ }

NetworkPanel::~NetworkPanel()
{ }

void
NetworkPanel::draw(HWND hwnd, HDC dc)
{
    RECT rgn;
    if (!GetUpdateRect(hwnd, &rgn, FALSE))
        return;

    PAINTSTRUCT ps;
    dc = BeginPaint(hwnd, &ps);       // FIXME: do we need the 'dc' parameter?

    // Outer rectangle
    GetClientRect(hwnd, &rgn);
    HGDIOBJ prev_pen = SelectObject(dc, GetStockObject(BLACK_PEN));
    MoveToEx(dc, rgn.left, rgn.top, 0);
    LineTo(dc, rgn.right, rgn.top);
    LineTo(dc, rgn.right, rgn.bottom);
    LineTo(dc, rgn.left, rgn.bottom);
    LineTo(dc, rgn.left, rgn.top);
    InflateRect(&rgn, -1, -1);
    SelectObject(dc, prev_pen);

    // Inner
    FillRect(dc, &rgn, (HBRUSH) GetStockObject(WHITE_BRUSH));
    SetTextColor(dc, RGB(0, 0, 0));

    HGDIOBJ prev_font = SelectObject(dc, m_Font);
    std::string text;
    if (!m_Exec.getNumActiveJobs())
        text = "Network: idle";
    else if (m_Exec.getNumActiveJobs() == 1)
        text = "Network: 1 job";
    else
        text = "Network: " + itoa(m_Exec.getNumActiveJobs()) + " jobs";
    DrawText(dc, text.data(), text.size(), &rgn, DT_CENTER | DT_VCENTER | DT_NOPREFIX);
    SelectObject(dc, prev_font);

    EndPaint(hwnd, &ps);
}

LRESULT
NetworkPanel::handle(HWND hwnd, UINT msg, WPARAM wparam, LPARAM lparam)
{
    switch (msg) {
     case WM_PAINT:
        draw(hwnd, HDC(wparam));
        return 0;
     default:
        return Window::handle(hwnd, msg, wparam, lparam);
    }
}

HWND
NetworkPanel::create(int x, int y, int nWidth, int nHeight, HWND hWndParent)
{
    m_Hwnd = Window::create(CLASS_NAME, "",
                            WS_CHILDWINDOW,
                            x, y, nWidth, nHeight, hWndParent, 0);
    return m_Hwnd;
}

void
NetworkPanel::update()
{
    InvalidateRect(m_Hwnd, 0, FALSE);
}

void
NetworkPanel::init()
{
    if (!m_Font) {
        HDC desktop_dc = GetDC(GetDesktopWindow());

        int height = -MulDiv(10, GetDeviceCaps(desktop_dc, LOGPIXELSY), 72);

        m_Font = CreateFont(height, 0, 0, 0,
                            FW_REGULAR,
                            FALSE, FALSE, FALSE,
                            ANSI_CHARSET,
                            OUT_DEFAULT_PRECIS, CLIP_DEFAULT_PRECIS,
                            DEFAULT_QUALITY, DEFAULT_PITCH | FF_SWISS,
                            "Arial");
        RECT size;
        size.left = size.top = 0;
        size.right = size.bottom = 99;
        HGDIOBJ prev = SelectObject(desktop_dc, m_Font);
        DrawText(desktop_dc, "Tp", 2, &size, DT_CALCRECT);
        SelectObject(desktop_dc, prev);
    
        m_DefaultWidth  = 12 * size.right;
        m_DefaultHeight = size.bottom + 5;
        ReleaseDC(GetDesktopWindow(), desktop_dc);

        registerWindowClass(CLASS_NAME, 0);
    }
}
