#ifndef WINGUI_H
#define WINGUI_H

#include <vector>
#include "api.h"
#include "data.h"
#include "selection.h"
#include "version.h"
#include "execute.h"
#include "networkpanel.h"
#include "initializer.h"

class StatusPanel;

enum {
    ID_FILE_CLOSE = 1000,
    ID_FILE_LOAD,
    ID_FILE_ASSIGN_DIRS,
    ID_FILE_NETCONFIG,
    ID_HELP_ABOUT,


    ID_GAME    = 10000,
    ID_RACE    = 12000,
    ID_ACTION  = 14000,
    ID_PROGRAM = 16000
};

class MainWindow : public Window {
    HWND m_Hwnd;

    Data& m_Data;

    Initializer m_Init;

    HMENU m_FileMenu;
    HMENU m_GameMenu;
    HMENU m_RaceMenu;
    HMENU m_ActionMenu;
    HMENU m_ProgramMenu;
    HMENU m_HelpMenu;
    HMENU m_FullMenu;

    HFONT m_BigFont;
    HFONT m_SmallFont;

    bool m_Terminated;

    void clearMenu(HMENU& m);
    void buildFileMenu();
    void buildGameMenu();
    void buildRaceMenu();
    void buildActionMenu();
    void buildProgramsMenu();
    void buildHelpMenu();

    void rebuildAllMenus();

    void selectGame(Game* g);
    void selectRace(Race* r);

    void runAction(Action* a);

    bool askYesNo(const char* format, int arg);
    void loadFile();

    void doRequestGC();

    void pushStatusPanel(StatusPanel* p);
    void recomputePanelSizes();
    void doPanelTimer();

    Selection m_Selection;
    
    std::vector<Game*> m_Games;
    std::vector<Race*> m_Races;
    std::vector<Action*> m_Actions;
    std::vector<Action*> m_ProgramActions;

    enum { NUM_PANELS = 3 };
    int m_nPanels;
    int m_PanelYAdjust;
    int m_PanelTimer;
    StatusPanel* m_Panels[NUM_PANELS];

    Executer m_Exec;

    NetworkPanel m_NetworkPanel;

    bool askWinplan();

 public:
    MainWindow(Data& data);

    HWND create();

    LRESULT handle(HWND hwng, UINT msg, WPARAM wparam, LPARAM lparam);

    bool isTerminated() const
        { return m_Terminated; }

    void loadFile(std::string name);

    void preInit();

    void postInit();

    HMENU getMenu();
};



#endif
